@@ -3,16 +3,16 @@
 # Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -388,6 +388,35 @@ class KeyBindings:
 
         return consumed
 
+    def load(self, keymap, handlers):
+        """ Takes the keymappings and tries to find a matching named
+           function in handlers.
+           keymap is a list of lists, each list contains 5 elements
+           If addUnbound is set to true, then at the end of loading all the
+           keybindings, any remaining functions will be unbound.
+        """
+
+
+        for i in keymap:
+            keysymstring = i[0]
+            modifierMask = i[1]
+            modifiers = i[2]
+            handler = i[3]
+            try:
+                clickCount = i[4]
+            except:
+                clickCount = 1
+
+            if handlers.has_key(handler):
+                # add the keybinding
+                self.add(KeyBinding( \
+                  keysymstring, modifierMask, modifiers, \
+                    handlers[handler], clickCount))
+            else:
+                debug.println(debug.LEVEL_WARNING, \
+                  "WARNING: could not find %s handler to associate " \
+                  "with keybinding." % handler)
+
     def validate(self):
         """Tries to find keybindings where the keysym is not set for the
         keyboard layout or where multiple keybindings map to the same
