@@ -1893,7 +1893,7 @@ def getListOfShortcuts(typeOfShortcuts):
             #
             clickCount = _("triple click")
         shortcut = (kb.handler.description, keybindings.getModifierNames\
-        (kb.modifiers) + keysymString.upper() + " " + clickCount)
+        (kb.modifiers) + keysymString.title() + " " + clickCount)
         shortcuts.append(shortcut)
         shortcuts = sorted(shortcuts, key=lambda shortcut: shortcut[1])
 
@@ -2005,8 +2005,6 @@ def init(registry):
     registry.registerEventListener(_onMouseButton,
                                    "mouse:button")
 
-    showSplashGUI()
-
     loadUserSettings()
 
     masks = []
@@ -2308,6 +2306,8 @@ def main():
     except:
         debug.printException(debug.LEVEL_SEVERE)
 
+    showSplashGUI()
+
     # Check to see if the user wants the configuration GUI. It's
     # done here so that the user's existing preferences can be used
     # to set the initial GUI state.  We'll also force the set to
